import{x as t,b as s,et as c}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3b17c15c-0394-44c3-99a5-ce447623eba6",e._sentryDebugIdIdentifier="sentry-dbid-3b17c15c-0394-44c3-99a5-ce447623eba6")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),c("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.0ee68a63.js.map
