import{d,eA as b,J as c,a as g,b as f,c as v,w as i,f as s}from"./outputWidgets.d6897520.js";import{B as _}from"./BaseLayout.a0b2c3e1.js";import{a as h}from"./asyncComputed.2c363ccc.js";import{P as y}from"./project.7c73974a.js";import"./console.526446d9.js";import{O as z}from"./organization.1bd1ec32.js";import"./index.a8a303e6.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.206ffdeb.js";import{S as I}from"./Sidebar.3d434e83.js";import{I as w,J as k,K as B,L as P,M as $,N as C,O as M,F as x,G as D,H as L}from"./icons.20b5fc8a.js";import"./gateway.c13063b9.js";import"./activeRecord.e97440b4.js";import"./pubsub.e0b33cd4.js";import"./index.40bea6c2.js";import"./Form.a2bccbf0.js";import"./Title.9e102f51.js";import"./index.65fddafd.js";import"./index.dcf9fd0a.js";import"./index.09e1dc09.js";import"./dayjs.dccbdd6f.js";import"./index.0f5fc52a.js";import"./index.fd09b35e.js";import"./TabPane.c8258ec5.js";import"./index.b11f642a.js";import"./index.7c1a9101.js";import"./index.e63bacfa.js";import"./index.30191c77.js";import"./index.33e7eca5.js";import"./index.16598f32.js";import"./index.a2784b6b.js";import"./index.59123055.js";import"./logo.084e5d7c.js";import"./Tooltip.446f8c24.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="66b95f5f-01de-45f6-a8c9-646f79ba3bb5",t._sentryDebugIdIdentifier="sentry-dbid-66b95f5f-01de-45f6-a8c9-646f79ba3bb5")}catch{}})();const bo=d({__name:"Project",setup(t){const p=b().params.projectId,{result:o}=h(()=>y.get(p).then(async a=>{const e=await z.get(a.organizationId);return{project:a,organization:e}})),l=c(()=>{var a,e,n,m;return((a=o.value)==null?void 0:a.organization)&&o.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(e=o.value)==null?void 0:e.organization)==null?void 0:n.name,path:`/organizations/${(m=o.value)==null?void 0:m.organization.id}`},{label:o.value.project.name,path:`/projects/${o.value.project.id}`}]:void 0}),u=c(()=>{var a;return(a=o.value)!=null&&a.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${o.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${o.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${o.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(a,e)=>{const n=g("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{bo as default};
//# sourceMappingURL=Project.90e255a1.js.map
