import{x as o,a,b as i,c,g as d,h as p,_,i as u,T as l,j as f,P as h,C as b,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.d6897520.js";import{u as k}from"./index.3b692b6d.js";import"./pubsub.e0b33cd4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="974c0bfd-5971-4c6b-b253-af5cd521be43",e._sentryDebugIdIdentifier="sentry-dbid-974c0bfd-5971-4c6b-b253-af5cd521be43")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.fde77a4e.js"),["assets/Player.fde77a4e.js","assets/index.40bea6c2.js","assets/outputWidgets.d6897520.js","assets/outputWidgets.8ce475af.css","assets/uuid.4307559f.js","assets/broker.2631cbda.js","assets/index.3b692b6d.js","assets/pubsub.e0b33cd4.js","assets/executeJs.8211d702.js","assets/icons.20b5fc8a.js","assets/CircularLoading.74c5b113.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.582e448c.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.1d151ab5.js","assets/Steps.998aa76d.css","assets/Modal.1a4e3f2f.js","assets/Modal.5aaf8eba.css","assets/executeJs.9c4b02ee.css","assets/WidgetsFrame.b500b4a0.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.f720947f.js","assets/broker.0cfcc9cb.css","assets/DashPlayer.8f9c2517.js","assets/geometryUtils.bf113e76.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.2c363ccc.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});l.init(),f(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.34482e75.js.map
