import{d,r as i,o as r,eP as l,b as f,et as u,eC as p,eN as y}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e67cd7b0-773c-43b6-aa36-c4ce6cfd81ea",e._sentryDebugIdIdentifier="sentry-dbid-e67cd7b0-773c-43b6-aa36-c4ce6cfd81ea")}catch{}})();const m=d({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=i(null);return r(()=>{s.value&&o.action.setElement(s.value),l.addAction(o.action)}),(a,t)=>(f(),u("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=c=>n("click")),onKeydown:t[1]||(t[1]=y(c=>n("click"),["enter"]))},p(a.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.f720947f.js.map
