import{M as r}from"./Modal.1a4e3f2f.js";import{d as a,H as c,r as d,a as _,b as f,et as l,f as n,w as i,bw as m,e as u,x as p}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="34abcc84-d31c-451e-9501-e88555c04f0e",e._sentryDebugIdIdentifier="sentry-dbid-34abcc84-d31c-451e-9501-e88555c04f0e")}catch{}})();const b=["src"],y=a({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,w)=>{const s=_("router-view");return f(),l(m,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const I=p(y,[["__scopeId","data-v-7e290e34"]]);export{I as default};
//# sourceMappingURL=Home.990c58db.js.map
