import{d as b,ez as g,eA as v,r as k,b as r,c as a,w as s,u as e,f as l,ew as i}from"./outputWidgets.d6897520.js";import{S as h,L as w}from"./SmartConsole.5f1c5f28.js";import{a as B}from"./asyncComputed.2c363ccc.js";import{H as C}from"./hooks.00c0c0b3.js";import{_ as H}from"./SaveButton.vue_vue_type_script_setup_true_lang.bca29f12.js";import{_ as I}from"./DocsButton.vue_vue_type_script_setup_true_lang.51351099.js";import{B as S}from"./BaseLayout.a0b2c3e1.js";import{_ as T,a as x}from"./HookSettings.vue_vue_type_script_setup_true_lang.42c92ec2.js";import{c as A}from"./index.65fddafd.js";import{A as _,T as D}from"./TabPane.c8258ec5.js";import"./forms.346cb6b2.js";import"./activeRecord.e97440b4.js";import"./pubsub.e0b33cd4.js";import"./dashes.dff0708d.js";import"./index.40bea6c2.js";import"./jobs.341e30c2.js";import"./workspaces.fb65e732.js";import"./icons.20b5fc8a.js";import"./Title.9e102f51.js";import"./index.a2784b6b.js";import"./uuid.4307559f.js";import"./ant-design.25ee6641.js";import"./index.e63bacfa.js";import"./index.dcf9fd0a.js";import"./index.30191c77.js";import"./index.0f5fc52a.js";import"./Form.a2bccbf0.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="1811832a-a878-49ad-b56d-650f781824b6",n._sentryDebugIdIdentifier="sentry-dbid-1811832a-a878-49ad-b56d-650f781824b6")}catch{}})();const ne=b({__name:"HookEditor",setup(n){const m=g(),p=v(),f=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=B(()=>C.get(p.params.hookPath)),c=w.create();return(R,d)=>(r(),a(S,null,{navbar:s(()=>[e(t)?(r(),a(e(A),{key:0,title:e(t).title,onBack:y},{footer:s(()=>[l(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:s(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[l(I,{path:"hooks"}),o.value==="settings"?(r(),a(H,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(T,{key:0,ref_key:"tester",ref:f,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),a(x,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:s(()=>{var u;return[e(t)&&o.value==="test"?(r(),a(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(u=f.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=HookEditor.65548185.js.map
