import{_ as w}from"./logo.084e5d7c.js";import{x as B,b as s,et as y,eD as C,eE as I,e as h,d as k,ez as L,a as D,u as e,c,bR as S,w as t,f as a,b2 as l,eC as _,cd as f,cP as N,t as R,eB as V,eY as E,bw as P,ew as T}from"./outputWidgets.d6897520.js";import{a as b}from"./console.526446d9.js";import{a as $}from"./asyncComputed.2c363ccc.js";import{a as j}from"./index.59123055.js";import{A as g}from"./index.dcf9fd0a.js";import{A as z,B as F,a as H,c as M}from"./index.65fddafd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="e436c23c-eeae-42fd-9d95-9448bc747051",o._sentryDebugIdIdentifier="sentry-dbid-e436c23c-eeae-42fd-9d95-9448bc747051")}catch{}})();const U={},v=o=>(C("data-v-439be421"),o=o(),I(),o),Y={class:"logo"},q=v(()=>h("img",{class:"logo-img",src:w,alt:"Abstra cloud logo"},null,-1)),G=v(()=>h("span",null,"Abstra Cloud",-1)),J=[q,G];function K(o,r){return s(),y("div",Y,J)}const O=B(U,[["render",K],["__scopeId","data-v-439be421"]]),Q=k({__name:"LoginBlock",setup(o){function r(p){const m=p.split("@")[0];return R.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(i=>i[0]).join("")}const d=L(),{result:n,loading:u,refetch:x}=$(async()=>b.getAuthor());function A(){b.removeAuthor(),x(),d.push({name:"login"})}return(p,m)=>{const i=D("router-link");return e(u)?(s(),c(e(S),{key:0})):e(n)?(s(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[a(e(g),{direction:"vertical"},{default:t(()=>[a(e(j),null,{default:t(()=>[l(_(e(n).claims.email),1)]),_:1}),a(e(f),{onClick:A},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[a(e(g),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(z),null,{default:t(()=>[l(_(r(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(s(),c(e(f),{key:2},{default:t(()=>[a(i,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),re=k({__name:"Navbar",props:{breadcrumb:{}},setup(o){return(r,d)=>(s(),c(e(M),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[r.breadcrumb?(s(),c(e(F),{key:0},{default:t(()=>[(s(!0),y(P,null,V(r.breadcrumb,(n,u)=>(s(),c(e(H),{key:u},{default:t(()=>[a(e(E),{to:n.path},{default:t(()=>[l(_(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):T("",!0)]),title:t(()=>[a(O)]),extra:t(()=>[a(Q)]),_:1}))}});export{re as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.206ffdeb.js.map
