import{d as l,J as c,b as n,et as a,e as o,bw as d,eB as r,ey as _,eC as i,ew as f,x as u}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="b2954490-924d-4ef1-b943-3328da32f2da",e._sentryDebugIdIdentifier="sentry-dbid-b2954490-924d-4ef1-b943-3328da32f2da")}catch{}})();const m={key:0,class:"p-steps p-component"},y={class:"p-steps-list"},b={class:"p-menuitem-link"},g={class:"p-steps-number"},I=l({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,p=c(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,w)=>e.stepsInfo?(n(),a("nav",m,[o("ol",y,[(n(!0),a(d,null,r(p.value,(k,t)=>(n(),a("li",{key:t,class:_(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[o("span",b,[o("span",g,i(t+1),1)])],2))),128))])])):f("",!0)}});const D=u(I,[["__scopeId","data-v-c6d9488a"]]);export{D as S};
//# sourceMappingURL=Steps.1d151ab5.js.map
