import{d as u,eA as f,J as b,b as y,c as _,u as g}from"./outputWidgets.d6897520.js";import{a as w}from"./asyncComputed.2c363ccc.js";import"./console.526446d9.js";import{M as m}from"./member.916242f8.js";import"./index.a8a303e6.js";import{_ as I}from"./CrudView.vue_vue_type_script_setup_true_lang.eece189e.js";import"./index.40bea6c2.js";import"./Form.a2bccbf0.js";import"./Title.9e102f51.js";import"./index.65fddafd.js";import"./index.dcf9fd0a.js";import"./index.09e1dc09.js";import"./dayjs.dccbdd6f.js";import"./index.0f5fc52a.js";import"./index.fd09b35e.js";import"./TabPane.c8258ec5.js";import"./index.b11f642a.js";import"./index.7c1a9101.js";import"./index.e63bacfa.js";import"./index.30191c77.js";import"./index.33e7eca5.js";import"./index.16598f32.js";import"./index.a2784b6b.js";import"./index.59123055.js";import"./gateway.c13063b9.js";import"./activeRecord.e97440b4.js";import"./pubsub.e0b33cd4.js";import"./icons.20b5fc8a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="77fdb579-4495-4c25-9d67-a61632c1dc2f",e._sentryDebugIdIdentifier="sentry-dbid-77fdb579-4495-4c25-9d67-a61632c1dc2f")}catch{}})();const V=u({__name:"Members",setup(e){const r=f().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await m.create(r,t.email),d()},{loading:p,result:l,refetch:d}=w(()=>m.list(r)),c=b(()=>{var t,i;return{columns:[{name:"Email"},{name:"Role"}],rows:(i=(t=l.value)==null?void 0:t.map(a=>({key:a.email,cells:[{text:a.email},{text:a.role}]})))!=null?i:[]}});return(t,i)=>(y(),_(I,{"entity-name":"members",loading:g(p),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{V as default};
//# sourceMappingURL=Members.546e295d.js.map
