import{cN as f}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="7dff37d1-fd1c-4acb-a85f-ce4a4635cd12",e._sentryDebugIdIdentifier="sentry-dbid-7dff37d1-fd1c-4acb-a85f-ce4a4635cd12")}catch{}})();const o=(e,d)=>{f.error({message:e,description:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.d1c280c1.js.map
