import{u as a}from"./icons.20b5fc8a.js";import{d as r,a as c,b as i,et as d,f,u as _,b2 as l,x as u}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1957bfa9-988f-455e-86c5-b4d2451ef08f",e._sentryDebugIdIdentifier="sentry-dbid-1957bfa9-988f-455e-86c5-b4d2451ef08f")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[f(s,{class:"icon",path:_(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.7d607c57.js.map
