import{R as n}from"./Title.9e102f51.js";import{F as a}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="449afe77-adb5-4b3e-bc6b-af06051a0588",e._sentryDebugIdIdentifier="sentry-dbid-449afe77-adb5-4b3e-bc6b-af06051a0588")}catch{}})();const r=a(n);export{r as A};
//# sourceMappingURL=index.a2784b6b.js.map
