import{C as a}from"./Title.9e102f51.js";import{F as n}from"./outputWidgets.d6897520.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6672d69a-1062-419c-bcf9-aea09fefa48a",e._sentryDebugIdIdentifier="sentry-dbid-6672d69a-1062-419c-bcf9-aea09fefa48a")}catch{}})();const r=n(a);export{r as A};
//# sourceMappingURL=index.7c1a9101.js.map
